@@ -371,12 +371,12 @@ def strip_trailing_comma(string):
 def stripQuotes(string):
     string = string.replace("'", "")
     string = string.replace('"', "")
-    string = string.replace('&apos;', "")
-    string = string.replace('&quot;', "")
+    string = string.replace('&apos_', "")
+    string = string.replace('&quot_', "")
     return string
 
 
 def sanitize_quotes(string):
-    string = string.replace("'", "&apos;")
-    string = string.replace('"', "&quot;")
+    string = string.replace("'", "&apos_")
+    string = string.replace('"', "&quot_")
     return string
